@@ -8,8 +8,10 @@ class Worker(object):
 
     def run(self, cls, *args, **kargs):
         ins = cls(*args, **kargs)
+        print ins
         while 1:
             task =  self.tq.GET_TASK()
+            print task
             if not task:
                 continue
             key, method, args = task
